==> nuxtjs-naive-ui-1.0.1.tgz: package/README.md <==
<!--
Get your module up and running quickly.

Find and replace all on all files (CMD+SHIFT+F):
- Name: My Module
- Package name: nuxtjs-naive-ui
- Description: My new Nuxt module
-->

# nuxtjs-naive-ui

[![npm version][npm-version-src]][npm-version-href]
[![npm downloads][npm-downloads-src]][npm-downloads-href]
[![License][license-src]][license-href]

English · [中文](README.zh_CN.md)

The official nuxt module for naive-ui that supports Nuxt.js SSR.

> [!IMPORTANT]  
> If you are using this module, make sure:
>
> 1. `@css-render/*` and `css-render` packages' version satisfies `>=0.15.4`.
> 2. Each of `@css-render/*` and `css-render` only to resolves 1 target. (No different versions of same package & No duplicate for the same version)
>
> You can search in lock file for `css-render` to check if there's duplicate.

## Quick Setup

Install the module to your Nuxt application with one command:

```bash
# npm
npx nuxi module add nuxtjs-naive-ui

# pnpm
pnpm dlx nuxi module add nuxtjs-naive-ui
```

[npm-version-src]: https://img.shields.io/npm/v/nuxtjs-naive-ui/latest.svg?style=flat&colorA=020420&colorB=00DC82
[npm-version-href]: https://npmjs.com/package/nuxtjs-naive-ui
[npm-downloads-src]: https://img.shields.io/npm/dm/nuxtjs-naive-ui.svg?style=flat&colorA=020420&colorB=00DC82
[npm-downloads-href]: https://npmjs.com/package/nuxtjs-naive-ui
[license-src]: https://img.shields.io/npm/l/nuxtjs-naive-ui.svg?style=flat&colorA=020420&colorB=00DC82
[license-href]: https://npmjs.com/package/nuxtjs-naive-ui
[nuxt-src]: https://img.shields.io/badge/Nuxt-020420?logo=nuxt.js
[nuxt-href]: https://nuxt.com

==> nuxtjs-naive-ui-1.0.2.tgz: package/README.md <==
<!--
Get your module up and running quickly.

Find and replace all on all files (CMD+SHIFT+F):
- Name: My Module
- Package name: nuxtjs-naive-ui
- Description: My new Nuxt module
-->

# nuxtjs-naive-ui

[![npm version][npm-version-src]][npm-version-href]
[![npm downloads][npm-downloads-src]][npm-downloads-href]
[![License][license-src]][license-href]

English · [中文](README.zh_CN.md)

The official nuxt module for naive-ui that supports Nuxt.js SSR and simplifies build configuration.

> [!IMPORTANT]  
> If you are using this module, make sure:
>
> 1. `@css-render/*` and `css-render` packages' version satisfies `>=0.15.14`.
> 2. Each of `@css-render/*` and `css-render` only resolves 1 target. (No different versions of same package & No duplicate for the same version)
>
> You can search in lock file for `css-render` to check if there's duplicate.

## Quick Setup

Install the module to your Nuxt application with one command:

```bash
# npm
npx nuxi module add nuxtjs-naive-ui

# pnpm
pnpm dlx nuxi module add nuxtjs-naive-ui
```

[npm-version-src]: https://img.shields.io/npm/v/nuxtjs-naive-ui/latest.svg?style=flat&colorA=020420&colorB=00DC82
[npm-version-href]: https://npmjs.com/package/nuxtjs-naive-ui
[npm-downloads-src]: https://img.shields.io/npm/dm/nuxtjs-naive-ui.svg?style=flat&colorA=020420&colorB=00DC82
[npm-downloads-href]: https://npmjs.com/package/nuxtjs-naive-ui
[license-src]: https://img.shields.io/npm/l/nuxtjs-naive-ui.svg?style=flat&colorA=020420&colorB=00DC82
[license-href]: https://npmjs.com/package/nuxtjs-naive-ui
[nuxt-src]: https://img.shields.io/badge/Nuxt-020420?logo=nuxt.js
[nuxt-href]: https://nuxt.com
